/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2009-2015.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#ifndef __FWGUIQT_BUILDER_NAMESPACE_HPP__
#define __FWGUIQT_BUILDER_NAMESPACE_HPP__

namespace fwGui
{
/**
 * @brief       The namespace fwGui::builder contains the classes for GUI elements builder implementation with the Qt library.
 * @namespace   fwGui::builder
 *
 * @date        2009-2010.
 *
 */

namespace builder
{

}
}
#endif /* __FWGUIQT_BUILDER_NAMESPACE_HPP__ */
